import { RedisCommand, RedisModules } from './commands';
import { ClientCommandOptions, WithPlugins } from './client';
import { RedisSocketOptions } from './socket';
import { ClusterNode } from './cluster-slots';
import { RedisLuaScript, RedisLuaScripts } from './lua-script';
import { CommandOptions } from './command-options';
export interface RedisClusterOptions<M = RedisModules, S = RedisLuaScripts> {
    rootNodes: Array<RedisSocketOptions>;
    modules?: M;
    scripts?: S;
    useReplicas?: boolean;
    maxCommandRedirections?: number;
}
export declare type RedisClusterType<M extends RedisModules, S extends RedisLuaScripts> = WithPlugins<M, S> & RedisCluster;
export default class RedisCluster<M extends RedisModules = RedisModules, S extends RedisLuaScripts = RedisLuaScripts> {
    #private;
    static defineCommand(on: any, name: string, command: RedisCommand): void;
    static create<M extends RedisModules, S extends RedisLuaScripts>(options: RedisClusterOptions): RedisClusterType<M, S>;
    static commandOptions(options: ClientCommandOptions): CommandOptions<ClientCommandOptions>;
    constructor(options: RedisClusterOptions<M, S>);
    connect(): Promise<void>;
    sendCommand<C extends RedisCommand>(firstKey: string | undefined, isReadonly: boolean | undefined, args: Array<string>, options?: ClientCommandOptions, redirections?: number): Promise<ReturnType<C['transformReply']>>;
    executeScript<S extends RedisLuaScript>(script: S, originalArgs: Array<unknown>, redisArgs: Array<string>, options?: ClientCommandOptions, redirections?: number): Promise<ReturnType<S['transformReply']>>;
    getMasters(): Array<ClusterNode<M, S>>;
    getSlotMaster(slot: number): ClusterNode<M, S>;
    disconnect(): Promise<void>;
}
